# file conventions

Many of `pyami` operations are on multiple files generated by globbing. Symbols embedded in `--outfile` will determine the action.

This is still experimental

## concatenation to named file
This is the default. All globbed filenames are concatenated into a single file:
with `myproject` set to `/Users/myproj`

```
pyami --proj ${myproject} --glob __CPROJECT/**/sections/**/fig.xml --outfile /Users/foo/bar.txt
```
will:
* set the symbol `__CPROJECT` to `/Users/myproj/` 
* glob all `fig.xml` files
* write the names to a single file `/Users/foo/bar.txt`

## concatenation to single CProject file
```
pyami --proj ${myproject} --glob _CPROJECT/**/sections/**/fig.xml --outfile __CPROJECT/foo/bar.txt
```
* set the symbol `__CPROJECT` to `/Users/myproj/` 
* glob all `fig.xml` files
* replace __CPROJECT in `outfile` to write the names to a single file `/Users/foo/bar.txt`

## concatenation to single CTree files
with `myproject` set to `/Users/myproj`
```
pyami --proj ${myproject} --glob __CPROJECT/**/sections/**/fig.xml --outfile __CTREE/foo/bar.txt
```
will use the symbol __CTREE to expand each CTree . The `outfile` name will be generated within each CTree 
thus generating a new file or directory in each CTree. Example:

```
/Users/
    myproj/
        PMC1/
            sections/
                figures/
                    fig1/
                        fig.xml
                    fig2/
                        fig.xml
        PMC2/
            sections/
                figures/
                    fig1/
                        fig.xml
                    fig3/
                        fig.xml

```

will generate:
```
/Users/myproj/PMC1/sections/figures/fig1/fig.xml
/Users/myproj/PMC1/sections/figures/fig2/fig.xml
/Users/myproj/PMC2/sections/figures/fig1/fig.xml
/Users/myproj/PMC2/sections/figures/fig2/fig.xml
```
`pyami` will then use the `__CPROJECT` value to convert these to:
```
__CPROJECT/PMC1/sections/figures/fig1/fig.xml
__CPROJECT/PMC1/sections/figures/fig2/fig.xml
__CPROJECT/PMC2/sections/figures/fig1/fig.xml
__CPROJECT/PMC2/sections/figures/fig2/fig.xml
```
and then use `__CTREE` to generate the CTrees as
```
__CPROJECT/PMC1
__CPROJECT/PMC2

```
For each file `pyami` will then deduce the CTree and generate 
```
__CPROJECT/PMC1/foo/bar.txt 
__CPROJECT/PMC2/foo/bar.txt 
```

## creation of new (sibling) file/s

default
```
pyami <some transformation> --glob <glob> --outfile `__PARENT/foo.txt`
```
The `_PARENT` symbol is expanded to the parent of the globbed files and used to generate a new sibling
e.g. 
```
    def example_split_pdf_txt_paras(self):
        proj_dir = self.pyamix.get_symbol("examples_test.p")
        self.pyamix.run_command([
            "--proj", proj_dir,
            "--glob", "${examples_test.p}/*/fulltext.pdf.txt",
            "--split", "txt2para",
            "--outfile", "__PARENT/fulltext.pdf.sec.txt",
            "--assert", "file_glob_count(${examples_test.p}/*/fulltext.pdf.sec.txt,291)"
        ])
```
generates a sibling file `fulltext.pdf.sec.txt`.
This is the default if `__PARENT` is omitted. This may change.